// @flow
import React from "react"
import ReactDOMServer from "react-dom/server"
import HTML from "../../client/support/HTML"
import Home from "../../client/components/Home"

import type {
	$Request,
	$Response,
	NextFunction
} from "express"

type MatcherCallback = (error: ?any, redirectLocation: ?string, renderProps: ?any) => void
type Matcher = (url: string, callback: MatcherCallback) => void
type Props = {
	match: Matcher
}

export default ({ match }: Props) => (req: $Request, res: $Response, next: NextFunction) => {
	match(req.url, (err, redirectLocation, renderProps) => {
		if (redirectLocation) {
			res.redirect(redirectLocation)
		}
		else if (renderProps) {			
			const text = ReactDOMServer.renderToStaticMarkup(
				<HTML title="Home">
					<Home />
				</HTML>
			)
			res.send(text)
			res.end()
		}
		else {
			next()
		}
	})
}

