// @flow
import webpack from "webpack"
import WebpackDevMiddleware from "webpack-dev-middleware"
import WebpackHotMiddleware from "webpack-hot-middleware"
import express from "express"
import { resolve } from "path"

import type {
	$Application
} from "express"

export default (server: $Application, config: any[]): WebpackHotMiddleware => {
	if (process.env["NODE_ENV"] === "development") { // eslint-disable-line no-undef
		const configs = config.filter(c => c.target === "web")
		const webpackConfig = webpack(configs)
		const devMiddleware = WebpackDevMiddleware(webpackConfig, {
			publicPath: "/assets/",
			stats: {
				colors: true
			},
		})
		const hotMiddleware = WebpackHotMiddleware(webpackConfig, {
			path: "/__webpack_hmr",
			log: console.log, // eslint-disable-line no-console
			heartbeat: 10 * 1000,
		})
		server.use(devMiddleware)
		server.use(hotMiddleware)
	}
	else {
		server.use("/assets", express.static(resolve("./build/client")))
	}
}

