const path = require("path")
const nodeExternals = require("webpack-node-externals")
const webpack = require("webpack")

const middleware = function(path) {
	if (process.env["NODE_ENV"] === "development") {
		return [
			"webpack-hot-middleware/client",
			path,
		]
	}
	else {
		return [path]	
	}
}

module.exports = [
	{
		entry: {
			server: middleware("./src/server/index.js"),
		},
		output: {
			path: path.resolve(__dirname, "./build"),
			filename: "[name].bundle.js",
			chunkFilename: "[id].bundle.js",
		},
		target: "node",
		externals: [nodeExternals()],
		devtool: "cheap-module-eval-source-map",
		module: {
			rules: [
				{
					test: /\.(graphql|gql)$/,
					exclude: /node_modules/,
					use: "graphql-tag/loader",
				},
				{
					test: /\.(js|jsx)$/,
					use: "babel-loader",
				},
			],
		},
	},
	{
		entry: {
			client: middleware("./src/client/index.js"),
 
		},
		output: {
			path: path.resolve(__dirname, "./build/client"),
			filename: "[name].js",
			publicPath: "/assets/",
		},
		target: "web",
		devtool: "#cheap-module-eval-source-map",
		devServer: {
			hot: true,
			contentBase: path.resolve(__dirname, 'build'),
			publicPath: '/assets/',
		},
		module: {
			rules: [
				{
					test: /\.(graphql|gql)$/,
					exclude: /node_modules/,
					use: "graphql-tag/loader",
				},
				{
					test: /\.(js|jsx)$/,
					use: "babel-loader",
				},
			],
		},
		plugins: [
			new webpack.optimize.CommonsChunkPlugin({
				name: "vendor",
				minChunks: function (module) {
				  // this assumes your vendor imports exist in the node_modules directory
				  return module.context && module.context.indexOf("node_modules") !== -1;
				}
			}),
			//CommonChunksPlugin will now extract all the common modules from vendor and main bundles
			new webpack.optimize.CommonsChunkPlugin({
				name: "manifest" //But since there are no more common modules between them we end up with just the runtime code included in the manifest file
			}),
			new webpack.HotModuleReplacementPlugin(),
		],
	},
]
